#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dnb_human_modeling_interfaces.swkik_constraint import SWKIKConstraint
from pycatia.dnb_human_sim_interfaces.worker_activity import WorkerActivity
from pycatia.product_structure_interfaces.product import Product


class MoveToPostureActivity(WorkerActivity):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DMAPSInterfaces.Activity
                |                         DNBHumanSimInterfaces.WorkerActivity
                |                             MoveToPostureActivity
                | 
                | The object that represents an MoveToPosture(MTP) Activity.
                | MTP allows to store a target posture for a specific manikin at a specific time
                | in the process. When a MTP is created, the current posture of the manikin along
                | with any constraints (if any).
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.move_to_posture_activity = com_object

    @property
    def acceleration_percent(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AccelerationPercent() As double
                | 
                |     Returns or Sets Acceleration Percentage

        :rtype: float
        """

        return self.move_to_posture_activity.AccelerationPercent

    @acceleration_percent.setter
    def acceleration_percent(self, value: float):
        """
        :param float value:
        """

        self.move_to_posture_activity.AccelerationPercent = value

    @property
    def corner_rounding(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CornerRounding() As double
                | 
                |     Returns or Sets Corner Rounding

        :rtype: float
        """

        return self.move_to_posture_activity.CornerRounding

    @corner_rounding.setter
    def corner_rounding(self, value: float):
        """
        :param float value:
        """

        self.move_to_posture_activity.CornerRounding = value

    @property
    def motion_basis(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MotionBasis() As HTSMotionBasis
                | 
                |     Returns or Sets Motion-Basis (see HTSMotionBasis for list of possible
                |     values)

        :return: enum hts_motion_basis
        :rtype: int
        """

        return self.move_to_posture_activity.MotionBasis

    @motion_basis.setter
    def motion_basis(self, value: int):
        """
        :param int value: enum hts_motion_basis
        """

        self.move_to_posture_activity.MotionBasis = value

    @property
    def referential(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Referential() As HTSManikinReferential
                | 
                |     Returns or Sets Manikin Referential (see HTSManikinReferential for list of
                |     possible values)

        :return: enum hts_manikin_referential
        :rtype: int
        """

        return self.move_to_posture_activity.Referential

    @referential.setter
    def referential(self, value: int):
        """
        :param int value: enum hts_manikin_referential
        """

        self.move_to_posture_activity.Referential = value

    @property
    def speed_percent(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SpeedPercent() As double
                | 
                |     Returns or Sets Speed Percentage

        :rtype: float
        """

        return self.move_to_posture_activity.SpeedPercent

    @speed_percent.setter
    def speed_percent(self, value: float):
        """
        :param float value:
        """

        self.move_to_posture_activity.SpeedPercent = value

    def add_constraint(self, pi_constraint: SWKIKConstraint) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddConstraint(SWKIKConstraint piConstraint)
                | 
                |     Adds the given constraint to MoveToPosture activity
                | 
                |     Parameters:
                | 
                |         piConstraint
                |             Constraint to be added. (see 
                | 
                |         SWKIKConstraint for list of possible values)

        :param SWKIKConstraint pi_constraint:
        :rtype: None
        """
        return self.move_to_posture_activity.AddConstraint(pi_constraint.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_constraint'
        # # vba_code = """
        # # Public Function add_constraint(move_to_posture_activity)
        # #     Dim piConstraint (2)
        # #     move_to_posture_activity.AddConstraint piConstraint
        # #     add_constraint = piConstraint
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def apply_posture_to_manikin(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ApplyPostureToManikin()
                | 
                |     Set the MoveToPosture(MTP) Activity's DegreeOfFreedom(DOF) values onto
                |     Manikin (which owns this MTP activity).

        :rtype: None
        """
        return self.move_to_posture_activity.ApplyPostureToManikin()

    def get_constraint(self, i_index: int) -> SWKIKConstraint:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetConstraint(long iIndex) As SWKIKConstraint
                | 
                |     Returns the constraint at given index
                | 
                |     Parameters:
                | 
                |         iIndex
                |             Index in the constraint-list to be retrieved 
                | 
                |     Returns:
                |         pioConstraint Constraint at given index (see SWKIKConstraint for list
                |         of possible values)

        :param int i_index:
        :rtype: SWKIKConstraint
        """
        return SWKIKConstraint(self.move_to_posture_activity.GetConstraint(i_index))

    def get_joint_values(self, o_joint_vals: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetJointValues(CATSafeArrayVariant oJointVals)
                | 
                |     Gets the Manikin's Position and Posture values in 137 doubles. (Array
                |     includeds Position information - first 6 values represent X,Y,Z and R,P,Y value
                |     of Manikin w.r.to its Father.)
                | 
                |     Parameters:
                | 
                |         oJointVals
                |             Joint Values

        :param tuple o_joint_vals:
        :rtype: None
        """
        return self.move_to_posture_activity.GetJointValues(o_joint_vals)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_joint_values'
        # # vba_code = """
        # # Public Function get_joint_values(move_to_posture_activity)
        # #     Dim oJointVals (2)
        # #     move_to_posture_activity.GetJointValues oJointVals
        # #     get_joint_values = oJointVals
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_number_of_constraints(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNumberOfConstraints() As long
                | 
                |     Returns the number of constraints on the MoveToPosture
                |     activity
                | 
                |     Returns:
                |         iNumber Number of Constraints

        :rtype: int
        """
        return self.move_to_posture_activity.GetNumberOfConstraints()

    def get_part_relation(self, e_ee: int, o_product: Product, o_offset_trans: tuple) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPartRelation(HTSEndEffector eEE,
                | Product oProduct,
                | CATSafeArrayVariant oOffsetTrans) As boolean
                | 
                |     DEPRECATED. DO NOT USE

        :param int e_ee: enum hts_end_effector
        :param Product o_product:
        :param tuple o_offset_trans:
        :rtype: bool
        """
        return self.move_to_posture_activity.GetPartRelation(e_ee, o_product.com_object, o_offset_trans)

    def get_position(self, o_trans_matrix: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetPosition(CATSafeArrayVariant oTransMatrix)
                | 
                |     This gets the position value in 12 doubles
                | 
                |     Parameters:
                | 
                |         oTransMatrix
                |             The first nine represent succcessively the components of the
                |             x-axis, y-axis, and z-axis. The last three represent the coordinates of the
                |             origin point.

        :param tuple o_trans_matrix:
        :rtype: None
        """
        return self.move_to_posture_activity.GetPosition(o_trans_matrix)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_position'
        # # vba_code = """
        # # Public Function get_position(move_to_posture_activity)
        # #     Dim oTransMatrix (2)
        # #     move_to_posture_activity.GetPosition oTransMatrix
        # #     get_position = oTransMatrix
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_posture_values(self, o_pos_vals: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetPostureValues(CATSafeArrayVariant oPosVals)
                | 
                |     Gets the Manikin's Posture values in 131 doubles. (This array excludes
                |     Position information)
                | 
                |     Parameters:
                | 
                |         oPosVals
                |             Posture values

        :param tuple o_pos_vals:
        :rtype: None
        """
        return self.move_to_posture_activity.GetPostureValues(o_pos_vals)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_posture_values'
        # # vba_code = """
        # # Public Function get_posture_values(move_to_posture_activity)
        # #     Dim oPosVals (2)
        # #     move_to_posture_activity.GetPostureValues oPosVals
        # #     get_posture_values = oPosVals
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_segment_values(self, in_seg_name: str, o_dof_vals: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetSegmentValues(CATBSTR inSegName,
                | CATSafeArrayVariant oDofVals)
                | 
                |     Gets the DOF values of the given segment from MoveToPosture
                |     activity
                | 
                |     Parameters:
                | 
                |         inSegName
                |             Name of the Segment 
                |         oDofVals
                |             Dof values of constraint, array of size 3

        :param str in_seg_name:
        :param tuple o_dof_vals:
        :rtype: None
        """
        return self.move_to_posture_activity.GetSegmentValues(in_seg_name, o_dof_vals)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_segment_values'
        # # vba_code = """
        # # Public Function get_segment_values(move_to_posture_activity)
        # #     Dim inSegName (2)
        # #     move_to_posture_activity.GetSegmentValues inSegName
        # #     get_segment_values = inSegName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def has_part_relation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func HasPartRelation() As boolean
                | 
                |     DEPRECATED. DO NOT USE

        :rtype: bool
        """
        return self.move_to_posture_activity.HasPartRelation()

    def remove_constraint(self, pi_constraint: SWKIKConstraint) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveConstraint(SWKIKConstraint piConstraint)
                | 
                |     Removes the given constraint from MoveToPosture activity
                | 
                |     Parameters:
                | 
                |         piConstraint
                |             Constraint to be removed. (see 
                | 
                |         SWKIKConstraint for list of possible values)

        :param SWKIKConstraint pi_constraint:
        :rtype: None
        """
        return self.move_to_posture_activity.RemoveConstraint(pi_constraint.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove_constraint'
        # # vba_code = """
        # # Public Function remove_constraint(move_to_posture_activity)
        # #     Dim piConstraint (2)
        # #     move_to_posture_activity.RemoveConstraint piConstraint
        # #     remove_constraint = piConstraint
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_current_constraint_set(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCurrentConstraintSet()
                | 
                |     Set the current Constraints existing on Manikin onto MoveToPosture activity

        :rtype: None
        """
        return self.move_to_posture_activity.SetCurrentConstraintSet()

    def set_joint_values(self, o_joint_vals: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetJointValues(CATSafeArrayVariant oJointVals)
                | 
                |     Sets the Manikin's Position and Posture values with 137 doubles. (Array
                |     should includes Position information - first 6 values represent X,Y,Z and R,P,Y
                |     value of Manikin w.r.to its Father.)
                | 
                |     Parameters:
                | 
                |         oJointVals
                |             Joint Values

        :param tuple o_joint_vals:
        :rtype: None
        """
        return self.move_to_posture_activity.SetJointValues(o_joint_vals)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_joint_values'
        # # vba_code = """
        # # Public Function set_joint_values(move_to_posture_activity)
        # #     Dim oJointVals (2)
        # #     move_to_posture_activity.SetJointValues oJointVals
        # #     set_joint_values = oJointVals
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_part_relation(self, e_ee: int, o_product: Product) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPartRelation(HTSEndEffector eEE,
                | Product oProduct)
                | 
                |     DEPRECATED. DO NOT USE

        :param int e_ee: enum hts_end_effector
        :param Product o_product:
        :rtype: None
        """
        return self.move_to_posture_activity.SetPartRelation(e_ee, o_product.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_part_relation'
        # # vba_code = """
        # # Public Function set_part_relation(move_to_posture_activity)
        # #     Dim eEE (2)
        # #     move_to_posture_activity.SetPartRelation eEE
        # #     set_part_relation = eEE
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_part_relation_with_offset(self, e_ee: int, o_product: Product, o_offset_trans: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPartRelationWithOffset(HTSEndEffector eEE,
                | Product oProduct,
                | CATSafeArrayVariant oOffsetTrans)
                | 
                |     DEPRECATED. DO NOT USE

        :param int e_ee: enum hts_end_effector
        :param Product o_product:
        :param tuple o_offset_trans:
        :rtype: None
        """
        return self.move_to_posture_activity.SetPartRelationWithOffset(e_ee, o_product.com_object, o_offset_trans)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_part_relation_with_offset'
        # # vba_code = """
        # # Public Function set_part_relation_with_offset(move_to_posture_activity)
        # #     Dim eEE (2)
        # #     move_to_posture_activity.SetPartRelationWithOffset eEE
        # #     set_part_relation_with_offset = eEE
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_position(self, o_trans_matrix: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPosition(CATSafeArrayVariant oTransMatrix)
                | 
                |     Sets the Manikin's position value in the MoveToPosture Activity. ( Pos.
                |     vals are w.r.to Manikin's Father )
                | 
                |     Parameters:
                | 
                |         oTransMatrix
                |             The array initialized with the components to set to the Manikin's
                |             position. The first nine represent succcessively the components of the x-axis,
                |             y-axis, and z-axis. The last three represent the coordinates of the origin
                |             point. 
                | 
                |     Example:
                | 
                |           This example sets the Position of Manikin
                |          oTransMatrix for MoveToPosture oMTP
                |
                |          Dim oTransMatrix( 11 )
                |          'Rotation( 45 degrees around the Z axis) components
                |          ' x axis components
                |          oTransMatrix( 0 ) = 0.707
                |          oTransMatrix( 1 ) = 0.707
                |          oTransMatrix( 2 ) = 0.0
                |          ' y axis components
                |          oTransMatrix( 3 ) = -0.707
                |          oTransMatrix( 4 ) = 0.707
                |          oTransMatrix( 5 ) = 0
                |          ' z axis components
                |          oTransMatrix( 6 ) = 0
                |          oTransMatrix( 7 ) = 0
                |          oTransMatrix( 8 ) = 1
                |          ' origin point coordinates
                |          oTransMatrix( 9 ) = 0
                |          oTransMatrix( 10 ) = 0
                |          oTransMatrix( 11 ) = 947.0
                | 
                |          oMTP.SetPosition(oTransMatrix)

        :param tuple o_trans_matrix:
        :rtype: None
        """
        return self.move_to_posture_activity.SetPosition(o_trans_matrix)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_position'
        # # vba_code = """
        # # Public Function set_position(move_to_posture_activity)
        # #     Dim oTransMatrix (2)
        # #     move_to_posture_activity.SetPosition oTransMatrix
        # #     set_position = oTransMatrix
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_posture_values(self, o_pos_vals: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetPostureValues(CATSafeArrayVariant oPosVals)
                | 
                |     Sets the Manikin's Posture values with 131 values
                | 
                |     Parameters:
                | 
                |         oPosVals
                |             Posture values

        :param tuple o_pos_vals:
        :rtype: None
        """
        return self.move_to_posture_activity.SetPostureValues(o_pos_vals)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_posture_values'
        # # vba_code = """
        # # Public Function set_posture_values(move_to_posture_activity)
        # #     Dim oPosVals (2)
        # #     move_to_posture_activity.SetPostureValues oPosVals
        # #     set_posture_values = oPosVals
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_segment_values(self, in_seg_name: str, o_dof_vals: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSegmentValues(CATBSTR inSegName,
                | CATSafeArrayVariant oDofVals)
                | 
                |     Sets the given DOF values for Segments from MoveToPosture
                |     activity
                | 
                |     Parameters:
                | 
                |         inSegName
                |             Name of the Segment 
                |         oDofVals
                |             Dof values of constraint, array of size 3

        :param str in_seg_name:
        :param tuple o_dof_vals:
        :rtype: None
        """
        return self.move_to_posture_activity.SetSegmentValues(in_seg_name, o_dof_vals)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_segment_values'
        # # vba_code = """
        # # Public Function set_segment_values(move_to_posture_activity)
        # #     Dim inSegName (2)
        # #     move_to_posture_activity.SetSegmentValues inSegName
        # #     set_segment_values = inSegName
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'MoveToPostureActivity(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.eno_cd5_interfaces.cd5_id import CD5ID
from pycatia.system_interfaces.any_object import AnyObject


class CD5Structure(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     CD5Structure
                | 
                | Represents the structure of an ENOVIA V6 object.
                | Role: It represents the structure of an ENOVIA V6 root object on which it is
                | possible to include some sub components. Its final purpose is to perform a
                | Partial Open on it, showing only the root and the sub components that were
                | previously included. It is managed by CD5Engine.
                | 
                | See also:
                |     CD5ID, CD5Engine
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.cd5_structure = com_object

    def get_root(self) -> CD5ID:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRoot() As CD5ID
                | 
                |     Returns the root ENOVIA V6 Identifier of the CD5Structure.
                | 
                |     Returns:
                |         The CD5ID. 
                |     Example:
                | 
                |           The following example creates a Structure from "RootProduct" and gets
                |           its root identifier.
                |
                |          Dim oCD5Engine As CD5Engine
                |          Set oCD5Engine = CATIA.GetItem("CD5Engine")
                |          Dim iRootCD5ID, oDummyCD5ID As CD5ID
                |          Set iRootCD5ID = oCD5Engine.GetIDFromTNR("CATProduct For Team", "RootProduct", "---")
                |          Dim oCD5Structure As CD5Structure
                |          Set oCD5Structure = oCD5Engine.GetStructure(iRootCD5ID)
                |          Set oDummyCD5ID = oCD5Structure.GetRoot()

        :rtype: CD5ID
        """
        return CD5ID(self.cd5_structure.GetRoot())

    def include(self, i_id: CD5ID) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Include(CD5ID iID)
                | 
                |     Includes an sub component (identified by its ENOVIA V6 Identifier) for a
                |     future Partial Open operation.
                | 
                |     Parameters:
                | 
                |         iID
                |             The ENOIACD5ID of the sub component to include. 
                | 
                |     Example:
                | 
                |           The following example creates a Structure from "RootProduct" and
                |           includes the object "IncludedPart".
                |
                |          Dim oCD5Engine As CD5Engine
                |          Set oCD5Engine = CATIA.GetItem("CD5Engine")
                |          Dim iRootCD5ID, iIncludedCD5ID As CD5ID
                |          Set iRootCD5ID = oCD5Engine.GetIDFromTNR("CATProduct For Team", "RootProduct", "---")
                |          Set iIncludedCD5ID = oCD5Engine.GetIDFromTNR("CATProduct For Team", "IncludedPart", "---")
                |          Dim oCD5Structure As CD5Structure
                |          Set oCD5Structure = oCD5Engine.GetStructure(iRootCD5ID)
                |          oCD5Structure.Include(iIncludedCD5ID)

        :param CD5ID i_id:
        :rtype: None
        """
        return self.cd5_structure.Include(i_id.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'include'
        # # vba_code = """
        # # Public Function include(cd5_structure)
        # #     Dim iID (2)
        # #     cd5_structure.Include iID
        # #     include = iID
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'CD5Structure(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_plant_ship_interfaces.psp_list_of_doubles import PSPListOfDoubles
from pycatia.system_interfaces.any_object import AnyObject


class PSPLightBend(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspLightBend
                | 
                | Represents the Light bendable object.
                | Role: It is used access light bendable data.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_light_bend = com_object

    def get_bend_data(self) -> PSPListOfDoubles:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetBendData() As PspListOfDoubles
                | 
                |     Returns the list of bend radii.
                | 
                |     Returns:
                |         List of bend radius (PspListOfDoubles).
                |
                |     Example:
                |
                |          Dim objThisIntf As PspLightBend
                |          Dim objArg1 As PspListOfDoubles
                |           ...
                |          Set objArg1 = objThisIntf.GetBendData

        :rtype: PSPListOfDoubles
        """
        return PSPListOfDoubles(self.psp_light_bend.GetBendData())

    def set_bend_data(self, i_list_of_bend_radius: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetBendData(CATSafeArrayVariant iListOfBendRadius)
                | 
                |     Sets a list of bend radii.
                | 
                |     Parameters:
                | 
                |         iListOfBendRadius
                |             List of bend radius. 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspLightBend
                |          Dim objArg1 As CATSafeArrayVariant
                |           ...
                |          objThisIntf.SetBendData objArg1

        :param tuple i_list_of_bend_radius:
        :rtype: None
        """
        return self.psp_light_bend.SetBendData(i_list_of_bend_radius)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_bend_data'
        # # vba_code = """
        # # Public Function set_bend_data(psp_light_bend)
        # #     Dim iListOfBendRadius (2)
        # #     psp_light_bend.SetBendData iListOfBendRadius
        # #     set_bend_data = iListOfBendRadius
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'PSPLightBend(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class PSPListOfLongs(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspListOfLongs
                | 
                | Represents a collection of Long values.
                | Role: Collection of Long.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_list_of_longs = com_object

    @property
    def count(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Count() As long (Read Only)
                | 
                |     Returns the number of long integers in the list.
                | 
                |     Example:
                |         This example retrieves in NumberOfLongs the number of long integers
                |         currently gathered in MyList.
                | 
                |          NumberOfLongs = MyList.Count

        :rtype: int
        """

        return self.psp_list_of_longs.Count

    def append(self, i_long: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Append(long iLong)
                | 
                |     Adds an long integer to the end of the list.
                | 
                |     Parameters:
                | 
                |         iLong
                |             The long integer to be added to the list. 
                | 
                |     Example:
                | 
                |           The following example appends a long integer to the
                |           list.
                |
                |          Dim MInteger As Long
                |          MInteger = 4
                |          Dim MyList As PspListOfLongs
                |          MyList.Append(MInteger)

        :param int i_long:
        :rtype: None
        """
        return self.psp_list_of_longs.Append(i_long)

    def item(self, i_index: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(long iIndex) As long
                | 
                |     Returns a long integer from its index in the list.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index of the first long integer in the collection is 1, and the
                |             index of the last long integer is Count. 
                | 
                |     Returns:
                |         the retrieved long integer. 
                |     Example:
                | 
                |           The following example returns in the third long integer in the
                |           list.
                |
                |          Dim MyLong As Integer
                |          Dim MyList As PspListOfLongs
                |          MyLong = PspListOfLongs.Item(3)

        :param int i_index:
        :rtype: int
        """
        return self.psp_list_of_longs.Item(i_index)

    def remove_by_index(self, i_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveByIndex(long iIndex)
                | 
                |     Remove a long integer from the list by specifying its position in the
                |     list.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The position of the long integer to be removed in the list.
                |
                |     Example:
                | 
                |           The following example removes the second entry in the list. Please
                |           note that the
                |          list index starts with 1.
                |
                |          Dim MyList As PspListOfLongs
                |          MyList.RemoveByIndex (2)

        :param int i_index:
        :rtype: None
        """
        return self.psp_list_of_longs.RemoveByIndex(i_index)

    def __repr__(self):
        return f'PSPListOfLongs(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.general_knowledge_interfaces.expert_rule_base_component_runtime import ExpertRuleBaseComponentRuntime
from pycatia.general_knowledge_interfaces.expert_rule_base_component_runtimes import ExpertRuleBaseComponentRuntimes

if TYPE_CHECKING:
    from pycatia.general_knowledge_interfaces.expert_rule_set import ExpertRuleSet


class ExpertRuleSetRuntime(ExpertRuleBaseComponentRuntime):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                    GenKnowledgeInterfaces.ExpertRuleBaseComponentRuntime
                |                         ExpertRuleSetRuntime
                | 
                | Represents the ExpertRuleSet object in the RelationSet.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.expert_rule_set_runtime = com_object

    @property
    def expert_rule_base_component_runtimes(self) -> ExpertRuleBaseComponentRuntimes:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ExpertRuleBaseComponentRuntimes() As
                | ExpertRuleBaseComponentRuntimes (Read Only)
                | 
                |     Returns the list of the RuleBaseComponent.

        :rtype: ExpertRuleBaseComponentRuntimes
        """

        return ExpertRuleBaseComponentRuntimes(self.expert_rule_set_runtime.ExpertRuleBaseComponentRuntimes)

    @property
    def rule_set_edition(self) -> 'ExpertRuleSet':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property RuleSetEdition() As ExpertRuleSet (Read Only)
                | 
                |     Returns the editable object corresponding to this ruleset. Be careful that,
                |     according to your licence, or the type of ruleset you're handling, you may not
                |     have the right to edit the ruleset.
                | 
                |     Example:
                | 
                |          Dim aRuleSetEdition As ExpertRuleSet
                |          Set aRuleSetEdition = aRuleSetRuntime.RuleSetEdition
                | 
                |          If not(aRuleSetEdition is Nothing) Then
                |            ' .. some actions
                |          End if

        :rtype: ExpertRuleSet
        """
        
        from pycatia.general_knowledge_interfaces.expert_rule_set import ExpertRuleSet
        return ExpertRuleSet(self.expert_rule_set_runtime.RuleSetEdition)

    def status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Status() As long
                | 
                |     Returns the Status of the ruleset: 1=OK, 0=KO.
                | 
                |     Example:
                | 
                |          Dim RuleSet1 As ExpertRuleSet 
                |          Set RuleSet1 = RuleSet.ExpertGenericRuleBaseComponentRuntimes.Item("RuleSet1")
                |          status = RuleSet1.Status ()
                |          
                | 
                |     Returns:
                |         Status of the ruleset

        :rtype: int
        """
        return self.expert_rule_set_runtime.Status()

    def __repr__(self):
        return f'ExpertRuleSetRuntime(name="{self.name}")'
